@@ -20,7 +20,13 @@ namespace bls {
 
 const size_t G1Element::SIZE;
 
-G1Element G1Element::FromBytes(const Bytes& bytes)
+G1Element G1Element::FromBytes(Bytes const bytes) {
+    G1Element ele = G1Element::FromBytesUnchecked(bytes);
+    ele.CheckValid();
+    return ele;
+}
+
+G1Element G1Element::FromBytesUnchecked(Bytes const bytes)
 {
     if (bytes.size() != SIZE) {
         throw std::invalid_argument("G1Element::FromBytes: Invalid size");
@@ -59,7 +65,6 @@ G1Element G1Element::FromBytes(const Bytes& bytes)
     }
     g1_read_bin(ele.p, buffer, G1Element::SIZE + 1);
     BLS::CheckRelicErrors();
-    ele.CheckValid();
     return ele;
 }
 
@@ -72,7 +77,6 @@ G1Element G1Element::FromNative(const g1_t element)
 {
     G1Element ele;
     g1_copy(ele.p, element);
-    ele.CheckValid();
     return ele;
 }
 
@@ -83,7 +87,7 @@ G1Element G1Element::FromMessage(const std::vector<uint8_t>& message,
     return FromMessage(Bytes(message), dst, dst_len);
 }
 
-G1Element G1Element::FromMessage(const Bytes& message,
+G1Element G1Element::FromMessage(Bytes const message,
                                  const uint8_t* dst,
                                  int dst_len)
 {
@@ -203,7 +207,13 @@ G1Element operator*(const bn_t& k, const G1Element& a) { return a * k; }
 
 const size_t G2Element::SIZE;
 
-G2Element G2Element::FromBytes(const Bytes& bytes)
+G2Element G2Element::FromBytes(Bytes const bytes) {
+    G2Element ele = G2Element::FromBytesUnchecked(bytes);
+    ele.CheckValid();
+    return ele;
+}
+
+G2Element G2Element::FromBytesUnchecked(Bytes const bytes)
 {
     if (bytes.size() != SIZE) {
         throw std::invalid_argument("G2Element::FromBytes: Invalid size");
@@ -247,7 +257,6 @@ G2Element G2Element::FromBytes(const Bytes& bytes)
 
     g2_read_bin(ele.q, buffer, G2Element::SIZE + 1);
     BLS::CheckRelicErrors();
-    ele.CheckValid();
     return ele;
 }
 
@@ -260,7 +269,6 @@ G2Element G2Element::FromNative(const g2_t element)
 {
     G2Element ele;
     g2_copy(ele.q, (g2_st*)element);
-    ele.CheckValid();
     return ele;
 }
 
@@ -271,7 +279,7 @@ G2Element G2Element::FromMessage(const std::vector<uint8_t>& message,
     return FromMessage(Bytes(message), dst, dst_len);
 }
 
-G2Element G2Element::FromMessage(const Bytes& message,
+G2Element G2Element::FromMessage(Bytes const message,
                                  const uint8_t* dst,
                                  int dst_len)
 {
@@ -388,15 +396,21 @@ G2Element operator*(const bn_t& k, const G2Element& a) { return a * k; }
 
 const size_t GTElement::SIZE;
 
-GTElement GTElement::FromBytes(const Bytes& bytes)
+GTElement GTElement::FromBytes(Bytes const bytes)
+{
+    GTElement ele = GTElement::FromBytesUnchecked(bytes);
+    if (gt_is_valid(*(gt_t*)&ele) == 0)
+        throw std::invalid_argument("GTElement is invalid");
+    return ele;
+}
+
+GTElement GTElement::FromBytesUnchecked(Bytes const bytes)
 {
     if (bytes.size() != SIZE) {
         throw std::invalid_argument("GTElement::FromBytes: Invalid size");
     }
     GTElement ele = GTElement();
     gt_read_bin(ele.r, bytes.begin(), GTElement::SIZE);
-    if (gt_is_valid(*(gt_t*)&ele) == 0)
-        throw std::invalid_argument("GTElement is invalid");
     BLS::CheckRelicErrors();
     return ele;
 }
